Custom backends
===============

FEI stream file backend
+++++++++++++++++++++++
This example is based on the specifications found on page 148 at `https://rsc.aux.eng.ufl.edu/_files/documents/820.pdf <https://rsc.aux.eng.ufl.edu/_files/documents/820.pdf>`__.

The stream file requries a coordinate transformation of the dwell points from the ...
